# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class AnsibleCollectionVersionSignatureResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'signed_collection': 'str',
        'pubkey_fingerprint': 'str',
        'signing_service': 'str'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'signed_collection': 'signed_collection',
        'pubkey_fingerprint': 'pubkey_fingerprint',
        'signing_service': 'signing_service'
    }

    def __init__(self, pulp_href=None, pulp_created=None, signed_collection=None, pubkey_fingerprint=None, signing_service=None, local_vars_configuration=None):  # noqa: E501
        """AnsibleCollectionVersionSignatureResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._signed_collection = None
        self._pubkey_fingerprint = None
        self._signing_service = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        self.signed_collection = signed_collection
        if pubkey_fingerprint is not None:
            self.pubkey_fingerprint = pubkey_fingerprint
        self.signing_service = signing_service

    @property
    def pulp_href(self):
        """Gets the pulp_href of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501


        :return: The pulp_href of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this AnsibleCollectionVersionSignatureResponse.


        :param pulp_href: The pulp_href of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this AnsibleCollectionVersionSignatureResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def signed_collection(self):
        """Gets the signed_collection of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501

        The content this signature is pointing to.  # noqa: E501

        :return: The signed_collection of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :rtype: str
        """
        return self._signed_collection

    @signed_collection.setter
    def signed_collection(self, signed_collection):
        """Sets the signed_collection of this AnsibleCollectionVersionSignatureResponse.

        The content this signature is pointing to.  # noqa: E501

        :param signed_collection: The signed_collection of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signed_collection is None:  # noqa: E501
            raise ValueError("Invalid value for `signed_collection`, must not be `None`")  # noqa: E501

        self._signed_collection = signed_collection

    @property
    def pubkey_fingerprint(self):
        """Gets the pubkey_fingerprint of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501

        The fingerprint of the public key.  # noqa: E501

        :return: The pubkey_fingerprint of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :rtype: str
        """
        return self._pubkey_fingerprint

    @pubkey_fingerprint.setter
    def pubkey_fingerprint(self, pubkey_fingerprint):
        """Sets the pubkey_fingerprint of this AnsibleCollectionVersionSignatureResponse.

        The fingerprint of the public key.  # noqa: E501

        :param pubkey_fingerprint: The pubkey_fingerprint of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :type: str
        """

        self._pubkey_fingerprint = pubkey_fingerprint

    @property
    def signing_service(self):
        """Gets the signing_service of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501

        The signing service used to create the signature.  # noqa: E501

        :return: The signing_service of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :rtype: str
        """
        return self._signing_service

    @signing_service.setter
    def signing_service(self, signing_service):
        """Sets the signing_service of this AnsibleCollectionVersionSignatureResponse.

        The signing service used to create the signature.  # noqa: E501

        :param signing_service: The signing_service of this AnsibleCollectionVersionSignatureResponse.  # noqa: E501
        :type: str
        """

        self._signing_service = signing_service

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsibleCollectionVersionSignatureResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsibleCollectionVersionSignatureResponse):
            return True

        return self.to_dict() != other.to_dict()
